aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/contrib/crf
diff options
context:
space:
mode:
authorGravatar Patrick Nguyen <drpng@google.com>2016-09-28 21:04:13 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2016-09-28 22:18:58 -0700
commitc672ae6c90f829eec7ab0dc593af8da15b90a363 (patch)
tree4b5484dca24cf72f911beae6396c3fba068160d8 /tensorflow/contrib/crf
parentc4a962829f2738e087c427d098d14337e85fdf6e (diff)
Fix spelling in docstrings.
Change: 134622348
Diffstat (limited to 'tensorflow/contrib/crf')
-rw-r--r--tensorflow/contrib/crf/python/ops/crf.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tensorflow/contrib/crf/python/ops/crf.py b/tensorflow/contrib/crf/python/ops/crf.py
index fbbbc2d5c1..dc8ab1407b 100644
--- a/tensorflow/contrib/crf/python/ops/crf.py
+++ b/tensorflow/contrib/crf/python/ops/crf.py
@@ -128,13 +128,13 @@ def crf_log_likelihood(inputs,
tag_indices,
sequence_lengths,
transition_params=None):
"""Computes the log-likehood of tag sequences in a CRF.
Args:
inputs: A [batch_size, max_seq_len, num_tags] tensor of unary potentials
to use as input to the CRF layer.
tag_indices: A [batch_size, max_seq_len] matrix of tag indices for which we
- compute the log-likehood.
+ compute the log-likelihood.
sequence_lengths: A [batch_size] vector of true sequence lengths.
transition_params: A [num_tags, num_tags] transition matrix, if available.
Returns:
@@ -291,7 +291,7 @@ def viterbi_decode(score, transition_params):
Returns:
viterbi: A [seq_len] list of integers containing the highest scoring tag
indicies.
- viterbi_score: A float containing the score for the viterbi sequence.
+ viterbi_score: A float containing the score for the Viterbi sequence.
"""
trellis = np.zeros_like(score)
backpointers = np.zeros_like(score, dtype=np.int32)
@@ -128,13 +128,13 @@ def crf_log_likelihood(inputs,
sequence_lengths,
transition_params=None):
- """Computes the log-likehood of tag sequences in a CRF.
+ """Computes the log-likelihood of tag sequences in a CRF.
Args:
inputs: A [batch_size, max_seq_len, num_tags] tensor of unary potentials